### 0.10.3 {small}`2024-05-13`

```{rubric} Features
```
* adds the flavor `seurat_v3_paper` to `pp.highly_variable_genes` {pr}`170` {smaller}`S Dicks`
* build docker images in github CI {pr}`177` {smaller}`T Korten (HZDR/Helmholtz AI)`

```{rubric} Performance
```
* updates the `qc_kernel` for sparse matrixes to only write once for each major axis {pr}`169` {smaller}`S Dicks`
* replaces sparse matrix operations with an element-wise kernel for `seurat_v3` and `seurat_v3_paper`. This should use less memory. {pr}`172` {smaller}`S Dicks`
* `pp.scale` now uses `cp.clip` for all clipping {pr}`173` {smaller}`S Dicks`
* updates `pp.highly_variable_genes` for the flavors `seurat` and `cell_ranger` {pr}`183` {smaller}`S Dicks`
* `pp.scale` now uses `RawKernels` for dense and csr {pr}`185` {smaller}`S Dicks`
* updates `gr.spatial_autocorr` to use a preallocation during the iterations {pr}`188` {smaller}`S Dicks`
* `_get_mean_var` for dense input now uses `cupy.ReductionKernel` to improve precision and speed {pr}`190` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* fixes a bug where the `pp.scale` would have issues with `int64` indexing {pr}`187` {smaller}`S Dicks`
